@@ -18,9 +18,8 @@ import json
 
 
 class JSONEncoder(json.JSONEncoder):
-
     def default(self, obj):
-        if hasattr(obj, 'repr_json'):
+        if hasattr(obj, "repr_json"):
             return obj.repr_json()
         else:
             return json.JSONEncoder.default(self, obj)
